@@ -1,101 +1,119 @@
 import json
-from typing import Any, Callable, ClassVar, Dict, List, Optional, Tuple
+from typing import Any, ClassVar, Dict, List, Literal, Optional, Tuple, Union
 
 from haystack import component, default_from_dict, default_to_dict, logging
-from haystack.dataclasses import ChatMessage, ChatRole, StreamingChunk, ToolCall, ToolCallResult
-from haystack.tools import Tool, _check_duplicate_tool_names, deserialize_tools_inplace
-from haystack.utils import Secret, deserialize_callable, deserialize_secrets_inplace, serialize_callable
+from haystack.dataclasses.chat_message import ChatMessage, ChatRole, ToolCall, ToolCallResult
+from haystack.dataclasses.streaming_chunk import (
+    AsyncStreamingCallbackT,
+    ComponentInfo,
+    StreamingCallbackT,
+    StreamingChunk,
+    SyncStreamingCallbackT,
+    select_streaming_callback,
+)
+from haystack.tools import (
+    Tool,
+    Toolset,
+    _check_duplicate_tool_names,
+    deserialize_tools_or_toolset_inplace,
+    serialize_tools_or_toolset,
+)
+from haystack.utils.auth import Secret, deserialize_secrets_inplace
+from haystack.utils.callable_serialization import deserialize_callable, serialize_callable
 
-from anthropic import Anthropic
+from anthropic import Anthropic, AsyncAnthropic
+from anthropic.resources.messages.messages import Message, RawMessageStreamEvent, Stream
+from anthropic.types import MessageParam, TextBlockParam, ToolParam, ToolResultBlockParam, ToolUseBlockParam
 
 logger = logging.getLogger(__name__)
 
 
 def _update_anthropic_message_with_tool_call_results(
-    tool_call_results: List[ToolCallResult], anthropic_msg: Dict[str, Any]
+    tool_call_results: List[ToolCallResult],
+    content: List[Union[TextBlockParam, ToolUseBlockParam, ToolResultBlockParam]],
 ) -> None:
     """
-    Update an Anthropic message with tool call results.
+    Update an Anthropic message content list with tool call results.
 
     :param tool_call_results: The list of ToolCallResults to update the message with.
-    :param anthropic_msg: The Anthropic message to update.
+    :param content: The Anthropic message content list to update.
     """
-    if "content" not in anthropic_msg:
-        anthropic_msg["content"] = []
-
     for tool_call_result in tool_call_results:
         if tool_call_result.origin.id is None:
             msg = "`ToolCall` must have a non-null `id` attribute to be used with Anthropic."
             raise ValueError(msg)
-        anthropic_msg["content"].append(
-            {
-                "type": "tool_result",
-                "tool_use_id": tool_call_result.origin.id,
-                "content": [{"type": "text", "text": tool_call_result.result}],
-                "is_error": tool_call_result.error,
-            }
+
+        tool_result_block = ToolResultBlockParam(
+            type="tool_result",
+            tool_use_id=tool_call_result.origin.id,
+            content=[{"type": "text", "text": tool_call_result.result}],
+            is_error=tool_call_result.error,
         )
+        content.append(tool_result_block)
 
 
-def _convert_tool_calls_to_anthropic_format(tool_calls: List[ToolCall]) -> List[Dict[str, Any]]:
+def _convert_tool_calls_to_anthropic_format(tool_calls: List[ToolCall]) -> List[ToolUseBlockParam]:
     """
     Convert a list of tool calls to the format expected by Anthropic Chat API.
 
     :param tool_calls: The list of ToolCalls to convert.
-    :return: A list of dictionaries in the format expected by Anthropic API.
+    :return: A list of ToolUseBlockParam objects in the format expected by Anthropic API.
     """
     anthropic_tool_calls = []
     for tc in tool_calls:
         if tc.id is None:
             msg = "`ToolCall` must have a non-null `id` attribute to be used with Anthropic."
             raise ValueError(msg)
-        anthropic_tool_calls.append(
-            {
-                "type": "tool_use",
-                "id": tc.id,
-                "name": tc.tool_name,
-                "input": tc.arguments,
-            }
+
+        tool_use_block = ToolUseBlockParam(
+            type="tool_use",
+            id=tc.id,
+            name=tc.tool_name,
+            input=tc.arguments,
         )
+        anthropic_tool_calls.append(tool_use_block)
     return anthropic_tool_calls
 
 
 def _convert_messages_to_anthropic_format(
     messages: List[ChatMessage],
-) -> Tuple[List[Dict[str, Any]], List[Dict[str, Any]]]:
+) -> Tuple[List[TextBlockParam], List[MessageParam]]:
     """
     Convert a list of messages to the format expected by Anthropic Chat API.
 
     :param messages: The list of ChatMessages to convert.
     :return: A tuple of two lists:
-        - A list of system message dictionaries in the format expected by Anthropic API.
-        - A list of non-system message dictionaries in the format expected by Anthropic API.
+        - A list of system message TextBlockParam objects in the format expected by Anthropic API.
+        - A list of non-system MessageParam objects in the format expected by Anthropic API.
     """
 
-    anthropic_system_messages = []
-    anthropic_non_system_messages = []
+    anthropic_system_messages: List[TextBlockParam] = []
+    anthropic_non_system_messages: List[MessageParam] = []
 
     i = 0
     while i < len(messages):
         message = messages[i]
 
-        # allow passing cache_control
-        cache_control = {"cache_control": message.meta.get("cache_control")} if "cache_control" in message.meta else {}
-
         # system messages have special format requirements for Anthropic API
         # they can have only type and text fields, and they need to be passed separately
         # to the Anthropic API endpoint
-        if message.is_from(ChatRole.SYSTEM):
-            anthropic_system_messages.append({"type": "text", "text": message.text, **cache_control})
+        if message.is_from(ChatRole.SYSTEM) and message.text:
+            sys_message = TextBlockParam(type="text", text=message.text)
+            if cache_control := message.meta.get("cache_control"):
+                sys_message["cache_control"] = cache_control
+            anthropic_system_messages.append(sys_message)
             i += 1
             continue
 
-        anthropic_msg: Dict[str, Any] = {"role": message._role.value, "content": [], **cache_control}
+        content: List[Union[TextBlockParam, ToolUseBlockParam, ToolResultBlockParam]] = []
 
         if message.texts and message.texts[0]:
-            anthropic_msg["content"].append({"type": "text", "text": message.texts[0]})
+            text_block = TextBlockParam(type="text", text=message.texts[0])
+            content.append(text_block)
+
         if message.tool_calls:
-            anthropic_msg["content"] += _convert_tool_calls_to_anthropic_format(message.tool_calls)
+            tool_use_blocks = _convert_tool_calls_to_anthropic_format(message.tool_calls)
+            content.extend(tool_use_blocks)
 
         if message.tool_call_results:
             results = message.tool_call_results.copy()
@@ -104,14 +122,20 @@ def _convert_messages_to_anthropic_format(
                 i += 1
                 results.extend(messages[i].tool_call_results)
 
-            _update_anthropic_message_with_tool_call_results(results, anthropic_msg)
-            anthropic_msg["role"] = "user"
+            _update_anthropic_message_with_tool_call_results(results, content)
 
-        if not anthropic_msg["content"]:
+        if not content:
             msg = "A `ChatMessage` must contain at least one `TextContent`, `ToolCall`, or `ToolCallResult`."
             raise ValueError(msg)
 
-        anthropic_non_system_messages.append(anthropic_msg)
+        # Anthropic only supports assistant and user roles in messages. User role is also used for tool messages.
+        # System messages are passed separately.
+        role: Union[Literal["assistant"], Literal["user"]] = "user"
+        if message._role == ChatRole.ASSISTANT:
+            role = "assistant"
+
+        anthropic_message = MessageParam(role=role, content=content)
+        anthropic_non_system_messages.append(anthropic_message)
         i += 1
 
     return anthropic_system_messages, anthropic_non_system_messages
@@ -135,10 +159,10 @@ class AnthropicChatGenerator:
 
     Usage example:
     ```python
-    from haystack_experimental.components.generators.anthropic import AnthropicChatGenerator
-    from haystack_experimental.dataclasses import ChatMessage
+    from haystack_integrations.components.generators.anthropic import AnthropicChatGenerator
+    from haystack.dataclasses import ChatMessage
 
-    generator = AnthropicChatGenerator(model="claude-3-5-sonnet-20240620",
+    generator = AnthropicChatGenerator(model="claude-sonnet-4-20250514",
                                        generation_kwargs={
                                            "max_tokens": 1000,
                                            "temperature": 0.7,
@@ -161,16 +185,20 @@ class AnthropicChatGenerator:
         "top_p",
         "top_k",
         "extra_headers",
+        "thinking",
     ]
 
     def __init__(
         self,
         api_key: Secret = Secret.from_env_var("ANTHROPIC_API_KEY"),  # noqa: B008
-        model: str = "claude-3-5-sonnet-20240620",
-        streaming_callback: Optional[Callable[[StreamingChunk], None]] = None,
+        model: str = "claude-sonnet-4-20250514",
+        streaming_callback: Optional[StreamingCallbackT] = None,
         generation_kwargs: Optional[Dict[str, Any]] = None,
         ignore_tools_thinking_messages: bool = True,
-        tools: Optional[List[Tool]] = None,
+        tools: Optional[Union[List[Tool], Toolset]] = None,
+        *,
+        timeout: Optional[float] = None,
+        max_retries: Optional[int] = None,
     ):
         """
         Creates an instance of AnthropicChatGenerator.
@@ -197,16 +225,33 @@ class AnthropicChatGenerator:
             `ignore_tools_thinking_messages` is `True`, the generator will drop so-called thinking messages when tool
             use is detected. See the Anthropic [tools](https://docs.anthropic.com/en/docs/tool-use#chain-of-thought-tool-use)
             for more details.
-        :param tools: A list of Tool objects that the model can use. Each tool should have a unique name.
-
+        :param tools: A list of Tool objects or a Toolset that the model can use. Each tool should have a unique name.
+        :param timeout:
+            Timeout for Anthropic client calls. If not set, it defaults to the default set by the Anthropic client.
+        :param max_retries:
+            Maximum number of retries to attempt for failed requests. If not set, it defaults to the default set by
+            the Anthropic client.
         """
-        _check_duplicate_tool_names(tools)
+        _check_duplicate_tool_names(list(tools or []))  # handles Toolset as well
 
         self.api_key = api_key
         self.model = model
         self.generation_kwargs = generation_kwargs or {}
         self.streaming_callback = streaming_callback
-        self.client = Anthropic(api_key=self.api_key.resolve_value())
+        self.timeout = timeout
+        self.max_retries = max_retries
+
+        client_kwargs: Dict[str, Any] = {"api_key": api_key.resolve_value()}
+        # We do this since timeout=None is not the same as not setting it in Anthropic
+        if timeout is not None:
+            client_kwargs["timeout"] = timeout
+        # We do this since max_retries must be an int when passing to Anthropic
+        if max_retries is not None:
+            client_kwargs["max_retries"] = max_retries
+
+        self.client = Anthropic(**client_kwargs)
+        self.async_client = AsyncAnthropic(**client_kwargs)
+
         self.ignore_tools_thinking_messages = ignore_tools_thinking_messages
         self.tools = tools
 
@@ -224,7 +269,6 @@ class AnthropicChatGenerator:
             The serialized component as a dictionary.
         """
         callback_name = serialize_callable(self.streaming_callback) if self.streaming_callback else None
-        serialized_tools = [tool.to_dict() for tool in self.tools] if self.tools else None
         return default_to_dict(
             self,
             model=self.model,
@@ -232,7 +276,9 @@ class AnthropicChatGenerator:
             generation_kwargs=self.generation_kwargs,
             api_key=self.api_key.to_dict(),
             ignore_tools_thinking_messages=self.ignore_tools_thinking_messages,
-            tools=serialized_tools,
+            tools=serialize_tools_or_toolset(self.tools),
+            timeout=self.timeout,
+            max_retries=self.max_retries,
         )
 
     @classmethod
@@ -245,7 +291,7 @@ class AnthropicChatGenerator:
             The deserialized component instance.
         """
         deserialize_secrets_inplace(data["init_parameters"], keys=["api_key"])
-        deserialize_tools_inplace(data["init_parameters"], key="tools")
+        deserialize_tools_or_toolset_inplace(data["init_parameters"], key="tools")
         init_params = data.get("init_parameters", {})
         serialized_callback_handler = init_params.get("streaming_callback")
         if serialized_callback_handler:
@@ -299,7 +345,10 @@ class AnthropicChatGenerator:
         )
         return message
 
-    def _convert_anthropic_chunk_to_streaming_chunk(self, chunk: Any) -> StreamingChunk:
+    @staticmethod
+    def _convert_anthropic_chunk_to_streaming_chunk(
+        chunk: RawMessageStreamEvent, component_info: ComponentInfo
+    ) -> StreamingChunk:
         """
         Converts an Anthropic StreamEvent to a StreamingChunk.
         """
@@ -307,7 +356,7 @@ class AnthropicChatGenerator:
         if chunk.type == "content_block_delta" and chunk.delta.type == "text_delta":
             content = chunk.delta.text
 
-        return StreamingChunk(content=content, meta=chunk.model_dump())
+        return StreamingChunk(content=content, meta=chunk.model_dump(), component_info=component_info)
 
     def _convert_streaming_chunks_to_chat_message(
         self, chunks: List[StreamingChunk], model: Optional[str] = None
@@ -323,11 +372,14 @@ class AnthropicChatGenerator:
         for chunk in chunks:
             chunk_type = chunk.meta.get("type")
             if chunk_type == "content_block_start":
-                if chunk.meta.get("content_block", {}).get("type") == "tool_use":
-                    delta_block = chunk.meta.get("content_block")
+                content_block = chunk.meta.get("content_block")
+                if content_block is None:
+                    msg = "Invalid streaming chunk. Expected 'content_block' field."
+                    raise ValueError(msg)
+                if content_block.get("type") == "tool_use":
                     current_tool_call = {
-                        "id": delta_block.get("id"),
-                        "name": delta_block.get("name"),
+                        "id": content_block.get("id"),
+                        "name": content_block.get("name"),
                         "arguments": "",
                     }
             elif chunk_type == "content_block_delta":
@@ -339,18 +391,25 @@ class AnthropicChatGenerator:
             elif chunk_type == "message_delta":
                 if chunk.meta.get("delta", {}).get("stop_reason") == "tool_use" and current_tool_call:
                     try:
-                        # arguments is a string, convert to json
+                        # When calling a tool with no arguments, the `arguments` field is an empty string.
+                        # We handle this by checking if `arguments` is empty and setting it to an empty dict.
+                        arguments = (
+                            json.loads(current_tool_call.get("arguments", "{}"))
+                            if current_tool_call.get("arguments")
+                            else {}
+                        )
                         tool_calls.append(
                             ToolCall(
                                 id=current_tool_call.get("id"),
                                 tool_name=str(current_tool_call.get("name")),
-                                arguments=json.loads(current_tool_call.get("arguments", {})),
+                                arguments=arguments,
                             )
                         )
                     except json.JSONDecodeError:
                         logger.warning(
                             "Anthropic returned a malformed JSON string for tool call arguments. "
-                            f"This tool call will be skipped. Arguments: {current_tool_call.get('arguments', '')}",
+                            "This tool call will be skipped. Arguments: {current_arguments}",
+                            current_arguments=current_tool_call.get("arguments", ""),
                         )
                     current_tool_call = None
 
@@ -358,7 +417,31 @@ class AnthropicChatGenerator:
 
         # Update meta information
         last_chunk_meta = chunks[-1].meta
-        usage = self._get_openai_compatible_usage(last_chunk_meta)
+
+        # Combine usage from first chunk (input_tokens) and last chunk (output_tokens)
+        combined_usage = {}
+
+        # Get input tokens from first chunk (message_start)
+        if chunks:
+            first_chunk_meta = chunks[0].meta
+            if first_chunk_meta.get("type") == "message_start":
+                first_chunk_usage = first_chunk_meta.get("message", {}).get("usage", {})
+                if "input_tokens" in first_chunk_usage:
+                    combined_usage["input_tokens"] = first_chunk_usage["input_tokens"]
+
+        # Get output tokens from last chunk (message_delta)
+        last_chunk_usage = last_chunk_meta.get("usage", {})
+        if "output_tokens" in last_chunk_usage:
+            combined_usage["output_tokens"] = last_chunk_usage["output_tokens"]
+        elif "completion_tokens" in last_chunk_usage:
+            combined_usage["output_tokens"] = last_chunk_usage["completion_tokens"]
+
+        # Add any other usage fields from the last chunk
+        for key, value in last_chunk_usage.items():
+            if key not in combined_usage:
+                combined_usage[key] = value
+
+        usage = self._get_openai_compatible_usage({"usage": combined_usage})
         message._meta.update(
             {
                 "model": model,
@@ -370,41 +453,34 @@ class AnthropicChatGenerator:
 
         return message
 
-    def _remove_cache_control(self, message: Dict[str, Any]) -> Dict[str, Any]:
-        """
-        Removes the cache_control key from the message.
-        :param message: The message to remove the cache_control key from.
-        :returns: The message with the cache_control key removed.
-        """
-        return {k: v for k, v in message.items() if k != "cache_control"}
-
-    @component.output_types(replies=List[ChatMessage])
-    def run(
+    def _prepare_request_params(
         self,
         messages: List[ChatMessage],
-        streaming_callback: Optional[Callable[[StreamingChunk], None]] = None,
         generation_kwargs: Optional[Dict[str, Any]] = None,
-        tools: Optional[List[Tool]] = None,
-    ):
+        tools: Optional[Union[List[Tool], Toolset]] = None,
+    ) -> Tuple[List[TextBlockParam], List[MessageParam], Dict[str, Any], List[ToolParam]]:
         """
-        Invokes the Anthropic API with the given messages and generation kwargs.
+        Prepare the parameters for the Anthropic API request.
 
         :param messages: A list of ChatMessage instances representing the input messages.
-        :param streaming_callback: A callback function that is called when a new token is received from the stream.
         :param generation_kwargs: Optional arguments to pass to the Anthropic generation endpoint.
-        :param tools: A list of tools for which the model can prepare calls. If set, it will override
-        the `tools` parameter set during component initialization.
-        :returns: A dictionary with the following keys:
-            - `replies`: The responses from the model
+        :param tools: A list of Tool objects or a Toolset that the model can use. Each tool should
+        have a unique name.
+        :returns: A tuple containing:
+            - system_messages: List of system messages in Anthropic format
+            - non_system_messages: List of non-system messages in Anthropic format
+            - generation_kwargs: Processed generation kwargs
+            - anthropic_tools: List of tools in Anthropic format
         """
         # update generation kwargs by merging with the generation kwargs passed to the run method
         generation_kwargs = {**self.generation_kwargs, **(generation_kwargs or {})}
         disallowed_params = set(generation_kwargs) - set(self.ALLOWED_PARAMS)
         if disallowed_params:
             logger.warning(
-                "Model parameters %s are not allowed and will be ignored. Allowed parameters are %s.",
-                disallowed_params,
-                self.ALLOWED_PARAMS,
+                "Model parameters {disallowed_params} are not allowed and will be ignored. "
+                "Allowed parameters are {allowed_params}.",
+                disallowed_params=disallowed_params,
+                allowed_params=self.ALLOWED_PARAMS,
             )
         generation_kwargs = {k: v for k, v in generation_kwargs.items() if k in self.ALLOWED_PARAMS}
 
@@ -413,8 +489,8 @@ class AnthropicChatGenerator:
         # prompt caching
         extra_headers = generation_kwargs.get("extra_headers", {})
         prompt_caching_on = "anthropic-beta" in extra_headers and "prompt-caching" in extra_headers["anthropic-beta"]
-        has_cached_messages = any("cache_control" in m for m in system_messages) or any(
-            "cache_control" in m for m in non_system_messages
+        has_cached_messages = any(m.get("cache_control") is not None for m in system_messages) or any(
+            m.get("cache_control") is not None for m in non_system_messages
         )
         if has_cached_messages and not prompt_caching_on:
             # this avoids Anthropic errors when prompt caching is not enabled
@@ -423,51 +499,49 @@ class AnthropicChatGenerator:
                 "Prompt caching is not enabled but you requested individual messages to be cached. "
                 "Messages will be sent to the API without prompt caching."
             )
-            system_messages = list(map(self._remove_cache_control, system_messages))
-            non_system_messages = list(map(self._remove_cache_control, non_system_messages))
+            for message in system_messages:
+                if message.get("cache_control"):
+                    del message["cache_control"]
 
         # tools management
         tools = tools or self.tools
-        _check_duplicate_tool_names(tools)
-        anthropic_tools = (
-            [
-                {
-                    "name": tool.name,
-                    "description": tool.description,
-                    "input_schema": tool.parameters,
-                }
-                for tool in tools
-            ]
-            if tools
-            else []
-        )
+        tools = list(tools) if isinstance(tools, Toolset) else tools
+        _check_duplicate_tool_names(tools)  # handles Toolset as well
 
-        streaming_callback = streaming_callback or self.streaming_callback
-        stream = streaming_callback is not None
+        anthropic_tools: List[ToolParam] = []
+        if tools:
+            for tool in tools:
+                anthropic_tools.append(
+                    ToolParam(name=tool.name, description=tool.description, input_schema=tool.parameters)
+                )
 
-        response = self.client.messages.create(
-            model=self.model,
-            messages=non_system_messages,
-            system=system_messages,
-            tools=anthropic_tools,
-            stream=stream,
-            max_tokens=generation_kwargs.pop("max_tokens", 1024),
-            **generation_kwargs,
-        )
+        return system_messages, non_system_messages, generation_kwargs, anthropic_tools
 
+    def _process_response(
+        self,
+        response: Union[Message, Stream[RawMessageStreamEvent]],
+        streaming_callback: Optional[SyncStreamingCallbackT] = None,
+    ) -> Dict[str, List[ChatMessage]]:
+        """
+        Process the response from the Anthropic API.
+
+        :param response: The response from the Anthropic API.
+        :param streaming_callback: A callback function that is called when a new token is received from the stream.
+        :returns: A dictionary containing the processed response as a list of ChatMessage objects.
+        """
         # workaround for https://github.com/DataDog/dd-trace-py/issues/12562
-        if stream:
+        # we cannot use isinstance(Stream)
+        if not isinstance(response, Message):
             chunks: List[StreamingChunk] = []
             model: Optional[str] = None
+            component_info = ComponentInfo.from_component(self)
             for chunk in response:
-                if chunk.type == "message_start":
-                    model = chunk.message.model
-                elif chunk.type in [
-                    "content_block_start",
-                    "content_block_delta",
-                    "message_delta",
-                ]:
-                    streaming_chunk = self._convert_anthropic_chunk_to_streaming_chunk(chunk)
+                if chunk.type in ["message_start", "content_block_start", "content_block_delta", "message_delta"]:
+                    # Extract model from message_start chunks
+                    if chunk.type == "message_start":
+                        model = chunk.message.model
+
+                    streaming_chunk = self._convert_anthropic_chunk_to_streaming_chunk(chunk, component_info)
                     chunks.append(streaming_chunk)
                     if streaming_callback:
                         streaming_callback(streaming_chunk)
@@ -480,3 +554,127 @@ class AnthropicChatGenerator:
                     self._convert_chat_completion_to_chat_message(response, self.ignore_tools_thinking_messages)
                 ]
             }
+
+    async def _process_response_async(
+        self,
+        response: Any,
+        streaming_callback: Optional[AsyncStreamingCallbackT] = None,
+    ) -> Dict[str, List[ChatMessage]]:
+        """
+        Process the response from the Anthropic API asynchronously.
+
+        :param response: The response from the Anthropic API.
+        :param streaming_callback: A callback function that is called when a new token is received from the stream.
+
+        :returns:
+            A dictionary containing the processed response as a list of ChatMessage objects.
+        """
+        # workaround for https://github.com/DataDog/dd-trace-py/issues/12562
+        stream = streaming_callback is not None
+        if stream:
+            chunks: List[StreamingChunk] = []
+            model: Optional[str] = None
+            component_info = ComponentInfo.from_component(self)
+            async for chunk in response:
+                if chunk.type == "message_start":
+                    model = chunk.message.model
+                elif chunk.type in [
+                    "content_block_start",
+                    "content_block_delta",
+                    "message_delta",
+                ]:
+                    streaming_chunk = self._convert_anthropic_chunk_to_streaming_chunk(chunk, component_info)
+                    chunks.append(streaming_chunk)
+                    if streaming_callback:
+                        await streaming_callback(streaming_chunk)
+
+            completion = self._convert_streaming_chunks_to_chat_message(chunks, model)
+            return {"replies": [completion]}
+        else:
+            return {
+                "replies": [
+                    self._convert_chat_completion_to_chat_message(response, self.ignore_tools_thinking_messages)
+                ]
+            }
+
+    @component.output_types(replies=List[ChatMessage])
+    def run(
+        self,
+        messages: List[ChatMessage],
+        streaming_callback: Optional[StreamingCallbackT] = None,
+        generation_kwargs: Optional[Dict[str, Any]] = None,
+        tools: Optional[Union[List[Tool], Toolset]] = None,
+    ) -> Dict[str, List[ChatMessage]]:
+        """
+        Invokes the Anthropic API with the given messages and generation kwargs.
+
+        :param messages: A list of ChatMessage instances representing the input messages.
+        :param streaming_callback: A callback function that is called when a new token is received from the stream.
+        :param generation_kwargs: Optional arguments to pass to the Anthropic generation endpoint.
+        :param tools: A list of Tool objects or a Toolset that the model can use. Each tool should
+        have a unique name. If set, it will override the `tools` parameter set during component initialization.
+        :returns: A dictionary with the following keys:
+            - `replies`: The responses from the model
+        """
+        system_messages, non_system_messages, generation_kwargs, anthropic_tools = self._prepare_request_params(
+            messages, generation_kwargs, tools
+        )
+
+        streaming_callback = select_streaming_callback(
+            init_callback=self.streaming_callback,
+            runtime_callback=streaming_callback,
+            requires_async=False,
+        )
+
+        response = self.client.messages.create(
+            model=self.model,
+            messages=non_system_messages,
+            system=system_messages,
+            tools=anthropic_tools,
+            stream=streaming_callback is not None,
+            max_tokens=generation_kwargs.pop("max_tokens", 1024),
+            **generation_kwargs,
+        )
+
+        return self._process_response(response=response, streaming_callback=streaming_callback)
+
+    @component.output_types(replies=List[ChatMessage])
+    async def run_async(
+        self,
+        messages: List[ChatMessage],
+        streaming_callback: Optional[StreamingCallbackT] = None,
+        generation_kwargs: Optional[Dict[str, Any]] = None,
+        tools: Optional[Union[List[Tool], Toolset]] = None,
+    ) -> Dict[str, List[ChatMessage]]:
+        """
+        Async version of the run method. Invokes the Anthropic API with the given messages and generation kwargs.
+
+        :param messages: A list of ChatMessage instances representing the input messages.
+        :param streaming_callback: A callback function that is called when a new token is received from the stream.
+        :param generation_kwargs: Optional arguments to pass to the Anthropic generation endpoint.
+        :param tools: A list of Tool objects or a Toolset that the model can use. Each tool should
+        have a unique name. If set, it will override the `tools` parameter set during component initialization.
+        :returns: A dictionary with the following keys:
+            - `replies`: The responses from the model
+        """
+        system_messages, non_system_messages, generation_kwargs, anthropic_tools = self._prepare_request_params(
+            messages, generation_kwargs, tools
+        )
+
+        streaming_callback = select_streaming_callback(
+            init_callback=self.streaming_callback,
+            runtime_callback=streaming_callback,
+            requires_async=True,
+        )
+
+        response = await self.async_client.messages.create(
+            model=self.model,
+            messages=non_system_messages,
+            system=system_messages,
+            tools=anthropic_tools,
+            stream=streaming_callback is not None,
+            max_tokens=generation_kwargs.pop("max_tokens", 1024),
+            **generation_kwargs,
+        )
+
+        return await self._process_response_async(response, streaming_callback)
