@@ -1,10 +1,11 @@
 # SPDX-FileCopyrightText: 2022-present deepset GmbH <info@deepset.ai>
 #
 # SPDX-License-Identifier: Apache-2.0
+
 import json
 import logging
 import os
-from unittest.mock import patch
+from unittest.mock import AsyncMock, patch
 
 import anthropic
 import pytest
@@ -15,11 +16,12 @@ from anthropic.types import (
     MessageStartEvent,
     TextBlockParam,
     TextDelta,
+    Usage,
 )
 from haystack import Pipeline
 from haystack.components.generators.utils import print_streaming_chunk
-from haystack.dataclasses import ChatMessage, ChatRole, StreamingChunk, ToolCall
-from haystack.tools import Tool
+from haystack.dataclasses import ChatMessage, ChatRole, ComponentInfo, StreamingChunk, ToolCall
+from haystack.tools import Tool, Toolset
 from haystack.utils.auth import Secret
 
 from haystack_integrations.components.generators.anthropic.chat.chat_generator import (
@@ -28,6 +30,21 @@ from haystack_integrations.components.generators.anthropic.chat.chat_generator i
 )
 
 
+def hello_world():
+    return "Hello, World!"
+
+
+@pytest.fixture
+def tool_with_no_parameters():
+    tool = Tool(
+        name="hello_world",
+        description="This prints hello world",
+        parameters={"properties": {}, "type": "object"},
+        function=hello_world,
+    )
+    return tool
+
+
 @pytest.fixture
 def tools():
     tool_parameters = {"type": "object", "properties": {"city": {"type": "string"}}, "required": ["city"]}
@@ -37,7 +54,6 @@ def tools():
         parameters=tool_parameters,
         function=lambda x: x,
     )
-
     return [tool]
 
 
@@ -54,7 +70,7 @@ def mock_anthropic_completion():
         completion = Message(
             id="foo",
             type="message",
-            model="claude-3-5-sonnet-20240620",
+            model="claude-sonnet-4-20250514",
             role="assistant",
             content=[TextBlockParam(type="text", text="Hello! I'm Claude.")],
             stop_reason="end_turn",
@@ -72,7 +88,7 @@ class TestAnthropicChatGenerator:
         monkeypatch.setenv("ANTHROPIC_API_KEY", "test-api-key")
         component = AnthropicChatGenerator()
         assert component.client.api_key == "test-api-key"
-        assert component.model == "claude-3-5-sonnet-20240620"
+        assert component.model == "claude-sonnet-4-20250514"
         assert component.streaming_callback is None
         assert not component.generation_kwargs
         assert component.tools is None
@@ -105,13 +121,13 @@ class TestAnthropicChatGenerator:
         monkeypatch.setenv("OPENAI_MAX_RETRIES", "10")
         component = AnthropicChatGenerator(
             api_key=Secret.from_token("test-api-key"),
-            model="claude-3-5-sonnet-20240620",
+            model="claude-sonnet-4-20250514",
             streaming_callback=print_streaming_chunk,
             generation_kwargs={"max_tokens": 10, "some_test_param": "test-params"},
             tools=[tool],
         )
         assert component.client.api_key == "test-api-key"
-        assert component.model == "claude-3-5-sonnet-20240620"
+        assert component.model == "claude-sonnet-4-20250514"
         assert component.streaming_callback is print_streaming_chunk
         assert component.generation_kwargs == {"max_tokens": 10, "some_test_param": "test-params"}
         assert component.tools == [tool]
@@ -123,13 +139,13 @@ class TestAnthropicChatGenerator:
         monkeypatch.setenv("OPENAI_TIMEOUT", "100")
         monkeypatch.setenv("OPENAI_MAX_RETRIES", "10")
         component = AnthropicChatGenerator(
-            model="claude-3-5-sonnet-20240620",
+            model="claude-sonnet-4-20250514",
             api_key=Secret.from_token("test-api-key"),
             streaming_callback=print_streaming_chunk,
             generation_kwargs={"max_tokens": 10, "some_test_param": "test-params"},
         )
         assert component.client.api_key == "test-api-key"
-        assert component.model == "claude-3-5-sonnet-20240620"
+        assert component.model == "claude-sonnet-4-20250514"
         assert component.streaming_callback is print_streaming_chunk
         assert component.generation_kwargs == {"max_tokens": 10, "some_test_param": "test-params"}
 
@@ -144,11 +160,13 @@ class TestAnthropicChatGenerator:
             "type": "haystack_integrations.components.generators.anthropic.chat.chat_generator.AnthropicChatGenerator",
             "init_parameters": {
                 "api_key": {"env_vars": ["ANTHROPIC_API_KEY"], "type": "env_var", "strict": True},
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "streaming_callback": None,
                 "ignore_tools_thinking_messages": True,
                 "generation_kwargs": {},
                 "tools": None,
+                "timeout": None,
+                "max_retries": None,
             },
         }
 
@@ -161,18 +179,20 @@ class TestAnthropicChatGenerator:
         monkeypatch.setenv("ENV_VAR", "test-api-key")
         component = AnthropicChatGenerator(
             api_key=Secret.from_env_var("ENV_VAR"),
-            model="claude-3-5-sonnet-20240620",
+            model="claude-sonnet-4-20250514",
             streaming_callback=print_streaming_chunk,
             generation_kwargs={"max_tokens": 10, "some_test_param": "test-params"},
             tools=[tool],
+            timeout=10.0,
+            max_retries=1,
         )
         data = component.to_dict()
 
-        assert data == {
+        expected_dict = {
             "type": "haystack_integrations.components.generators.anthropic.chat.chat_generator.AnthropicChatGenerator",
             "init_parameters": {
                 "api_key": {"env_vars": ["ENV_VAR"], "type": "env_var", "strict": True},
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "streaming_callback": "haystack.components.generators.utils.print_streaming_chunk",
                 "ignore_tools_thinking_messages": True,
                 "generation_kwargs": {"max_tokens": 10, "some_test_param": "test-params"},
@@ -191,9 +211,22 @@ class TestAnthropicChatGenerator:
                         "type": "haystack.tools.tool.Tool",
                     }
                 ],
+                "timeout": 10.0,
+                "max_retries": 1,
             },
         }
 
+        # add outputs_to_string, inputs_from_state and outputs_to_state tool parameters for compatibility with
+        # haystack-ai>=2.12.0
+        if hasattr(tool, "outputs_to_string"):
+            expected_dict["init_parameters"]["tools"][0]["data"]["outputs_to_string"] = tool.outputs_to_string
+        if hasattr(tool, "inputs_from_state"):
+            expected_dict["init_parameters"]["tools"][0]["data"]["inputs_from_state"] = tool.inputs_from_state
+        if hasattr(tool, "outputs_to_state"):
+            expected_dict["init_parameters"]["tools"][0]["data"]["outputs_to_state"] = tool.outputs_to_state
+
+        assert data == expected_dict
+
     def test_from_dict(self, monkeypatch):
         """
         Test that the AnthropicChatGenerator component can be deserialized from a dictionary.
@@ -203,7 +236,7 @@ class TestAnthropicChatGenerator:
             "type": "haystack_integrations.components.generators.anthropic.chat.chat_generator.AnthropicChatGenerator",
             "init_parameters": {
                 "api_key": {"env_vars": ["ANTHROPIC_API_KEY"], "type": "env_var", "strict": True},
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "streaming_callback": "haystack.components.generators.utils.print_streaming_chunk",
                 "generation_kwargs": {"max_tokens": 10, "some_test_param": "test-params"},
                 "tools": [
@@ -226,7 +259,7 @@ class TestAnthropicChatGenerator:
         component = AnthropicChatGenerator.from_dict(data)
 
         assert isinstance(component, AnthropicChatGenerator)
-        assert component.model == "claude-3-5-sonnet-20240620"
+        assert component.model == "claude-sonnet-4-20250514"
         assert component.streaming_callback is print_streaming_chunk
         assert component.generation_kwargs == {"max_tokens": 10, "some_test_param": "test-params"}
         assert component.api_key == Secret.from_env_var("ANTHROPIC_API_KEY")
@@ -243,7 +276,7 @@ class TestAnthropicChatGenerator:
             "type": "haystack_integrations.components.generators.anthropic.chat.chat_generator.AnthropicChatGenerator",
             "init_parameters": {
                 "api_key": {"env_vars": ["ANTHROPIC_API_KEY"], "type": "env_var", "strict": True},
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "streaming_callback": "haystack.components.generators.utils.print_streaming_chunk",
                 "generation_kwargs": {"max_tokens": 10, "some_test_param": "test-params"},
             },
@@ -283,7 +316,7 @@ class TestAnthropicChatGenerator:
         assert len(response["replies"]) == 1
         assert isinstance(response["replies"][0], ChatMessage)
         assert "Hello! I'm Claude." in response["replies"][0].text
-        assert response["replies"][0].meta["model"] == "claude-3-5-sonnet-20240620"
+        assert response["replies"][0].meta["model"] == "claude-sonnet-4-20250514"
         assert response["replies"][0].meta["finish_reason"] == "end_turn"
 
     def test_check_duplicate_tool_names(self, tools):
@@ -296,12 +329,13 @@ class TestAnthropicChatGenerator:
         Test converting Anthropic stream events to Haystack StreamingChunks
         """
         component = AnthropicChatGenerator(api_key=Secret.from_token("test-api-key"))
+        component_info = ComponentInfo.from_component(component)
 
         # Test text delta chunk
         text_delta_chunk = ContentBlockDeltaEvent(
             type="content_block_delta", index=0, delta=TextDelta(type="text_delta", text="Hello, world!")
         )
-        streaming_chunk = component._convert_anthropic_chunk_to_streaming_chunk(text_delta_chunk)
+        streaming_chunk = component._convert_anthropic_chunk_to_streaming_chunk(text_delta_chunk, component_info)
         assert streaming_chunk.content == "Hello, world!"
         assert streaming_chunk.meta == {
             "type": "content_block_delta",
@@ -317,14 +351,20 @@ class TestAnthropicChatGenerator:
                 "type": "message",
                 "role": "assistant",
                 "content": [],
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "stop_reason": None,
                 "stop_sequence": None,
                 "usage": {"input_tokens": 25, "output_tokens": 1},
             },
         )
-        streaming_chunk = component._convert_anthropic_chunk_to_streaming_chunk(message_start_chunk)
+        streaming_chunk = component._convert_anthropic_chunk_to_streaming_chunk(message_start_chunk, component_info)
         assert streaming_chunk.content == ""
+
+        # remove fields not present in the pinned version of the Anthropic SDK.
+        # This ensures the test passes with both the pinned and the latest version of the Anthropic SDK.
+        streaming_chunk.meta["message"]["usage"].pop("server_tool_use", None)
+        streaming_chunk.meta["message"]["usage"].pop("service_tier", None)
+
         assert streaming_chunk.meta == {
             "type": "message_start",
             "message": {
@@ -332,7 +372,7 @@ class TestAnthropicChatGenerator:
                 "type": "message",
                 "role": "assistant",
                 "content": [],
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "stop_reason": None,
                 "stop_sequence": None,
                 "usage": {
@@ -350,13 +390,14 @@ class TestAnthropicChatGenerator:
             index=1,
             content_block={"type": "tool_use", "id": "toolu_123", "name": "weather", "input": {"city": "Paris"}},
         )
-        streaming_chunk = component._convert_anthropic_chunk_to_streaming_chunk(tool_use_chunk)
+        streaming_chunk = component._convert_anthropic_chunk_to_streaming_chunk(tool_use_chunk, component_info)
         assert streaming_chunk.content == ""
         assert streaming_chunk.meta == {
             "type": "content_block_start",
             "index": 1,
             "content_block": {"type": "tool_use", "id": "toolu_123", "name": "weather", "input": {"city": "Paris"}},
         }
+        assert streaming_chunk.component_info.type.endswith("chat_generator.AnthropicChatGenerator")
 
     def test_convert_streaming_chunks_to_chat_message(self):
         """
@@ -364,10 +405,29 @@ class TestAnthropicChatGenerator:
         """
         # Create a sequence of streaming chunks that simulate Anthropic's response
         chunks = [
+            # Message start with input tokens
+            StreamingChunk(
+                content="",
+                meta={
+                    "type": "message_start",
+                    "message": {
+                        "id": "msg_123",
+                        "type": "message",
+                        "role": "assistant",
+                        "content": [],
+                        "model": "claude-sonnet-4-20250514",
+                        "stop_reason": None,
+                        "stop_sequence": None,
+                        "usage": {"input_tokens": 25, "output_tokens": 0},
+                    },
+                },
+                component_info=ComponentInfo.from_component(self),
+            ),
             # Initial text content
             StreamingChunk(
                 content="",
                 meta={"type": "content_block_start", "index": 0, "content_block": {"type": "text", "text": ""}},
+                component_info=ComponentInfo.from_component(self),
             ),
             StreamingChunk(
                 content="Let me check",
@@ -376,6 +436,7 @@ class TestAnthropicChatGenerator:
                     "index": 0,
                     "delta": {"type": "text_delta", "text": "Let me check"},
                 },
+                component_info=ComponentInfo.from_component(self),
             ),
             StreamingChunk(
                 content=" the weather",
@@ -424,7 +485,7 @@ class TestAnthropicChatGenerator:
         ]
 
         component = AnthropicChatGenerator(api_key=Secret.from_token("test-api-key"))
-        message = component._convert_streaming_chunks_to_chat_message(chunks, model="claude-3-sonnet")
+        message = component._convert_streaming_chunks_to_chat_message(chunks, model="claude-sonnet-4-20250514")
 
         # Verify the message content
         assert message.text == "Let me check the weather"
@@ -437,10 +498,10 @@ class TestAnthropicChatGenerator:
         assert tool_call.arguments == {"city": "Paris"}
 
         # Verify meta information
-        assert message._meta["model"] == "claude-3-sonnet"
+        assert message._meta["model"] == "claude-sonnet-4-20250514"
         assert message._meta["index"] == 0
         assert message._meta["finish_reason"] == "tool_use"
-        assert message._meta["usage"] == {"completion_tokens": 40}
+        assert message._meta["usage"] == {"prompt_tokens": 25, "completion_tokens": 40}
 
     def test_convert_streaming_chunks_to_chat_message_malformed_json(self, caplog):
         """
@@ -502,7 +563,7 @@ class TestAnthropicChatGenerator:
         ]
 
         component = AnthropicChatGenerator(api_key=Secret.from_token("test-api-key"))
-        message = component._convert_streaming_chunks_to_chat_message(chunks, model="claude-3-sonnet")
+        message = component._convert_streaming_chunks_to_chat_message(chunks, model="claude-sonnet-4-20250514")
 
         # Verify the message content is preserve
         assert message.text == "Let me check the weather"
@@ -514,12 +575,139 @@ class TestAnthropicChatGenerator:
         with caplog.at_level(logging.WARNING):
             assert "Anthropic returned a malformed JSON string" in caplog.text
 
+    def test_convert_streaming_chunks_to_chat_message_tool_call_with_empty_arguments(self):
+        """
+        Test converting streaming chunks with an empty tool call arguments
+        """
+        chunks = [
+            # Message start with input tokens
+            StreamingChunk(
+                content="",
+                meta={
+                    "type": "message_start",
+                    "message": {
+                        "id": "msg_456",
+                        "type": "message",
+                        "role": "assistant",
+                        "content": [],
+                        "model": "claude-sonnet-4-20250514",
+                        "stop_reason": None,
+                        "stop_sequence": None,
+                        "usage": {"input_tokens": 50, "output_tokens": 0},
+                    },
+                },
+            ),
+            StreamingChunk(
+                content="",
+                meta={
+                    "content_block": {"citations": None, "text": "", "type": "text"},
+                    "index": 0,
+                    "type": "content_block_start",
+                },
+            ),
+            StreamingChunk(
+                content="Certainly! I can",
+                meta={
+                    "delta": {"text": "Certainly! I can", "type": "text_delta"},
+                    "index": 0,
+                    "type": "content_block_delta",
+                },
+            ),
+            StreamingChunk(
+                content=' help you print "Hello World" using the available',
+                meta={
+                    "delta": {"text": ' help you print "Hello World" using the available', "type": "text_delta"},
+                    "index": 0,
+                    "type": "content_block_delta",
+                },
+            ),
+            StreamingChunk(
+                content=" tool. Let's use the \"",
+                meta={
+                    "delta": {"text": " tool. Let's use the \"", "type": "text_delta"},
+                    "index": 0,
+                    "type": "content_block_delta",
+                },
+            ),
+            StreamingChunk(
+                content='hello_world" function to accomplish this task.',
+                meta={
+                    "delta": {"text": 'hello_world" function to accomplish this task.', "type": "text_delta"},
+                    "index": 0,
+                    "type": "content_block_delta",
+                },
+            ),
+            StreamingChunk(
+                content="",
+                meta={
+                    "content_block": {
+                        "id": "toolu_014yzmmeNPAuTuiN92qV6LKr",
+                        "input": {},
+                        "name": "hello_world",
+                        "type": "tool_use",
+                    },
+                    "index": 1,
+                    "type": "content_block_start",
+                },
+            ),
+            StreamingChunk(
+                content="",
+                meta={
+                    "delta": {"partial_json": "", "type": "input_json_delta"},
+                    "index": 1,
+                    "type": "content_block_delta",
+                },
+            ),
+            StreamingChunk(
+                content="",
+                meta={
+                    "delta": {"stop_reason": "tool_use", "stop_sequence": None},
+                    "type": "message_delta",
+                    "usage": {
+                        "cache_creation_input_tokens": None,
+                        "cache_read_input_tokens": None,
+                        "input_tokens": None,
+                        "output_tokens": 69,
+                        "server_tool_use": None,
+                    },
+                },
+            ),
+        ]
+
+        component = AnthropicChatGenerator(api_key=Secret.from_token("test-api-key"))
+        message = component._convert_streaming_chunks_to_chat_message(chunks, model="claude-sonnet-4-20250514")
+
+        # Verify the message content
+        assert message.text == (
+            'Certainly! I can help you print "Hello World" using the available tool. Let\'s use the "hello_world" '
+            "function to accomplish this task."
+        )
+
+        # Verify tool calls
+        assert len(message.tool_calls) == 1
+        tool_call = message.tool_calls[0]
+        assert tool_call.id == "toolu_014yzmmeNPAuTuiN92qV6LKr"
+        assert tool_call.tool_name == "hello_world"
+        assert tool_call.arguments == {}
+
+        # Verify meta information
+        assert message._meta["model"] == "claude-sonnet-4-20250514"
+        assert message._meta["index"] == 0
+        assert message._meta["finish_reason"] == "tool_use"
+        assert message._meta["usage"] == {
+            "cache_creation_input_tokens": None,
+            "cache_read_input_tokens": None,
+            "completion_tokens": 69,
+            "prompt_tokens": 50,
+            "server_tool_use": None,
+        }
+
     def test_serde_in_pipeline(self):
         tool = Tool(name="name", description="description", parameters={"x": {"type": "string"}}, function=print)
 
         generator = AnthropicChatGenerator(
             api_key=Secret.from_env_var("ANTHROPIC_API_KEY", strict=False),
-            model="claude-3-5-sonnet-20240620",
+            model="claude-sonnet-4-20250514",
             generation_kwargs={"temperature": 0.6},
             tools=[tool],
         )
@@ -529,15 +717,17 @@ class TestAnthropicChatGenerator:
 
         pipeline_dict = pipeline.to_dict()
         type_ = "haystack_integrations.components.generators.anthropic.chat.chat_generator.AnthropicChatGenerator"
-        assert pipeline_dict == {
+
+        expected_dict = {
             "metadata": {},
             "max_runs_per_component": 100,
+            "connection_type_validation": True,
             "components": {
                 "generator": {
                     "type": type_,
                     "init_parameters": {
                         "api_key": {"type": "env_var", "env_vars": ["ANTHROPIC_API_KEY"], "strict": False},
-                        "model": "claude-3-5-sonnet-20240620",
+                        "model": "claude-sonnet-4-20250514",
                         "generation_kwargs": {"temperature": 0.6},
                         "ignore_tools_thinking_messages": True,
                         "streaming_callback": None,
@@ -552,12 +742,34 @@ class TestAnthropicChatGenerator:
                                 },
                             }
                         ],
+                        "timeout": None,
+                        "max_retries": None,
                     },
                 }
             },
             "connections": [],
         }
 
+        if not hasattr(pipeline, "_connection_type_validation"):
+            expected_dict.pop("connection_type_validation")
+
+        # add outputs_to_string, inputs_from_state and outputs_to_state tool parameters for compatibility with
+        # haystack-ai>=2.12.0
+        if hasattr(tool, "outputs_to_string"):
+            expected_dict["components"]["generator"]["init_parameters"]["tools"][0]["data"]["outputs_to_string"] = (
+                tool.outputs_to_string
+            )
+        if hasattr(tool, "inputs_from_state"):
+            expected_dict["components"]["generator"]["init_parameters"]["tools"][0]["data"]["inputs_from_state"] = (
+                tool.inputs_from_state
+            )
+        if hasattr(tool, "outputs_to_state"):
+            expected_dict["components"]["generator"]["init_parameters"]["tools"][0]["data"]["outputs_to_state"] = (
+                tool.outputs_to_state
+            )
+
+        assert pipeline_dict == expected_dict
+
         pipeline_yaml = pipeline.dumps()
 
         new_pipeline = Pipeline.loads(pipeline_yaml)
@@ -577,7 +789,7 @@ class TestAnthropicChatGenerator:
         assert len(results["replies"]) == 1
         message: ChatMessage = results["replies"][0]
         assert "Paris" in message.text
-        assert "claude-3-5-sonnet-20240620" in message.meta["model"]
+        assert "claude-sonnet-4-20250514" in message.meta["model"]
         assert message.meta["finish_reason"] == "end_turn"
 
     @pytest.mark.skipif(
@@ -608,16 +820,18 @@ class TestAnthropicChatGenerator:
             def __call__(self, chunk: StreamingChunk) -> None:
                 self.counter += 1
                 self.responses += chunk.content if chunk.content else ""
+                assert chunk.component_info is not None
+                assert chunk.component_info.type.endswith("chat_generator.AnthropicChatGenerator")
 
         callback = Callback()
-        component = AnthropicChatGenerator(streaming_callback=callback)
-        results = component.run([ChatMessage.from_user("What's the capital of France?")])
 
+        component = AnthropicChatGenerator(streaming_callback=callback, timeout=30.0, max_retries=1)
+        results = component.run([ChatMessage.from_user("What's the capital of France?")])
         assert len(results["replies"]) == 1
         message: ChatMessage = results["replies"][0]
         assert "Paris" in message.text
 
-        assert "claude-3-5-sonnet-20240620" in message.meta["model"]
+        assert "claude-sonnet-4-20250514" in message.meta["model"]
         assert message.meta["finish_reason"] == "end_turn"
 
         assert callback.counter > 1
@@ -834,6 +1048,59 @@ class TestAnthropicChatGenerator:
         assert len(final_message.text) > 0
         assert "paris" in final_message.text.lower()
 
+    @pytest.mark.skipif(
+        not os.environ.get("ANTHROPIC_API_KEY", None),
+        reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
+    )
+    @pytest.mark.integration
+    def test_live_run_with_toolset(self):
+        """
+        Integration test that the AnthropicChatGenerator component can run with a Toolset.
+        """
+
+        def weather_function(city: str) -> str:
+            """Get weather information for a city."""
+            weather_data = {"Paris": "22°C, sunny", "London": "15°C, rainy", "Tokyo": "18°C, cloudy"}
+            return weather_data.get(city, "Weather data not available")
+
+        def echo_function(text: str) -> str:
+            """Echo a text."""
+            return text
+
+        # Create tools
+        weather_tool = Tool(
+            name="weather",
+            description="Get weather information for a city",
+            parameters={"type": "object", "properties": {"city": {"type": "string"}}, "required": ["city"]},
+            function=weather_function,
+        )
+
+        echo_tool = Tool(
+            name="echo",
+            description="Echo a text",
+            parameters={"type": "object", "properties": {"text": {"type": "string"}}, "required": ["text"]},
+            function=echo_function,
+        )
+
+        # Create Toolset
+        toolset = Toolset([weather_tool, echo_tool])
+
+        # Test with weather query
+        initial_messages = [ChatMessage.from_user("What's the weather like in Tokyo?")]
+        component = AnthropicChatGenerator(tools=toolset)
+        results = component.run(messages=initial_messages)
+
+        assert len(results["replies"]) == 1
+        message = results["replies"][0]
+
+        assert message.tool_calls
+        tool_call = message.tool_call
+        assert isinstance(tool_call, ToolCall)
+        assert tool_call.id is not None
+        assert tool_call.tool_name == "weather"
+        assert tool_call.arguments == {"city": "Tokyo"}
+        assert message.meta["finish_reason"] == "tool_use"
+
     @pytest.mark.skipif(
         not os.environ.get("ANTHROPIC_API_KEY", None),
         reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
@@ -850,7 +1117,7 @@ class TestAnthropicChatGenerator:
         assert len(results["replies"]) == 1
         message = results["replies"][0]
 
-        # this is Antropic thinking message prior to tool call
+        # this is Anthropic thinking message prior to tool call
         assert message.text is not None
         assert "weather" in message.text.lower()
         assert "paris" in message.text.lower()
@@ -876,6 +1143,47 @@ class TestAnthropicChatGenerator:
         assert len(final_message.text) > 0
         assert "paris" in final_message.text.lower()
 
+    @pytest.mark.skipif(
+        not os.environ.get("ANTHROPIC_API_KEY", None),
+        reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
+    )
+    @pytest.mark.integration
+    def test_live_run_with_tool_with_no_args_streaming(self, tool_with_no_parameters):
+        """
+        Integration test that the AnthropicChatGenerator component can run with a tool that has no arguments and
+        streaming.
+        """
+        initial_messages = [ChatMessage.from_user("Print Hello World using the print hello world tool.")]
+        component = AnthropicChatGenerator(tools=[tool_with_no_parameters], streaming_callback=print_streaming_chunk)
+        results = component.run(messages=initial_messages)
+
+        assert len(results["replies"]) == 1
+        message = results["replies"][0]
+
+        # this is Anthropic thinking message prior to tool call
+        assert message.text is not None
+
+        # now we have the tool call
+        assert message.tool_calls
+        tool_call = message.tool_call
+        assert isinstance(tool_call, ToolCall)
+        assert tool_call.id is not None
+        assert tool_call.tool_name == "hello_world"
+        assert tool_call.arguments == {}
+        assert message.meta["finish_reason"] == "tool_use"
+
+        new_messages = [
+            *initial_messages,
+            message,
+            ChatMessage.from_tool(tool_result="Hello World!", origin=tool_call),
+        ]
+        results = component.run(new_messages)
+        assert len(results["replies"]) == 1
+        final_message = results["replies"][0]
+        assert not final_message.tool_calls
+        assert len(final_message.text) > 0
+        assert "hello" in final_message.text.lower()
+
     @pytest.mark.skipif(
         not os.environ.get("ANTHROPIC_API_KEY", None),
         reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
@@ -1016,7 +1324,7 @@ class TestAnthropicChatGenerator:
             "type": "haystack_integrations.components.generators.anthropic.chat.chat_generator.AnthropicChatGenerator",
             "init_parameters": {
                 "api_key": {"env_vars": ["ANTHROPIC_API_KEY"], "strict": True, "type": "env_var"},
-                "model": "claude-3-5-sonnet-20240620",
+                "model": "claude-sonnet-4-20250514",
                 "generation_kwargs": {"extra_headers": {"anthropic-beta": "prompt-caching-2024-07-31"}},
             },
         }
@@ -1054,3 +1362,175 @@ class TestAnthropicChatGenerator:
         else:
             assert token_usage["cache_creation_input_tokens"] == 0
             assert token_usage["cache_read_input_tokens"] == 0
+
+
+class TestAnthropicChatGeneratorAsync:
+    @pytest.fixture
+    async def mock_anthropic_completion_async(self):
+        with patch("anthropic.resources.messages.AsyncMessages.create") as mock_anthropic:
+            completion = Message(
+                id="foo",
+                type="message",
+                model="claude-sonnet-4-20250514",
+                role="assistant",
+                content=[TextBlockParam(type="text", text="Hello! I'm Claude.")],
+                stop_reason="end_turn",
+                usage=Usage(input_tokens=10, output_tokens=20),
+            )
+            # Make the mock return an awaitable
+            mock_anthropic.return_value = AsyncMock(return_value=completion)()
+            yield mock_anthropic
+
+    @pytest.fixture
+    async def mock_anthropic_completion_async_with_tool(self):
+        with patch("anthropic.resources.messages.AsyncMessages.create") as mock_anthropic:
+            completion = Message(
+                id="foo",
+                type="message",
+                model="claude-sonnet-4-20250514",
+                role="assistant",
+                content=[
+                    TextBlockParam(type="text", text="Let me check the weather for you."),
+                    {"type": "tool_use", "id": "tool_123", "name": "weather", "input": {"city": "Paris"}},
+                ],
+                stop_reason="tool_use",
+                usage=Usage(input_tokens=10, output_tokens=20),
+            )
+            # Make the mock return an awaitable
+            mock_anthropic.return_value = AsyncMock(return_value=completion)()
+            yield mock_anthropic
+
+    @pytest.mark.asyncio
+    async def test_run_async(self, chat_messages, mock_anthropic_completion_async, monkeypatch):
+        """
+        Test that the async run method of AnthropicChatGenerator works correctly.
+        """
+        monkeypatch.setenv("ANTHROPIC_API_KEY", "test-api-key")
+        component = AnthropicChatGenerator()
+        response = await component.run_async(chat_messages)
+
+        # check that the component returns the correct ChatMessage response
+        assert isinstance(response, dict)
+        assert "replies" in response
+        assert isinstance(response["replies"], list)
+        assert len(response["replies"]) == 1
+        assert [isinstance(reply, ChatMessage) for reply in response["replies"]]
+
+    @pytest.mark.asyncio
+    async def test_run_async_with_params(self, chat_messages, mock_anthropic_completion_async):
+        """
+        Test that the async run method of AnthropicChatGenerator works with parameters.
+        """
+        component = AnthropicChatGenerator(
+            api_key=Secret.from_token("test-api-key"), generation_kwargs={"max_tokens": 10, "temperature": 0.5}
+        )
+        response = await component.run_async(chat_messages)
+
+        # Check that the component calls the Anthropic API with the correct parameters
+        _, kwargs = mock_anthropic_completion_async.call_args
+        assert kwargs["max_tokens"] == 10
+        assert kwargs["temperature"] == 0.5
+
+        # Check that the component returns the correct response
+        assert isinstance(response, dict)
+        assert "replies" in response
+        assert isinstance(response["replies"], list)
+        assert len(response["replies"]) == 1
+        assert isinstance(response["replies"][0], ChatMessage)
+        assert "Hello! I'm Claude." in response["replies"][0].text
+        assert response["replies"][0].meta["model"] == "claude-sonnet-4-20250514"
+        assert response["replies"][0].meta["finish_reason"] == "end_turn"
+
+    @pytest.mark.asyncio
+    @pytest.mark.skipif(
+        not os.environ.get("ANTHROPIC_API_KEY", None),
+        reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
+    )
+    @pytest.mark.integration
+    async def test_live_run_async(self):
+        """
+        Integration test that the async run method of AnthropicChatGenerator works with default parameters.
+        """
+        component = AnthropicChatGenerator()
+        results = await component.run_async(messages=[ChatMessage.from_user("What's the capital of France?")])
+        assert len(results["replies"]) == 1
+        message: ChatMessage = results["replies"][0]
+        assert "Paris" in message.text
+        assert "claude-sonnet-4-20250514" in message.meta["model"]
+        assert message.meta["finish_reason"] == "end_turn"
+
+    @pytest.mark.asyncio
+    @pytest.mark.skipif(
+        not os.environ.get("ANTHROPIC_API_KEY", None),
+        reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
+    )
+    @pytest.mark.integration
+    async def test_live_run_async_with_streaming(self):
+        """
+        Test that the async run method of AnthropicChatGenerator works with streaming.
+        """
+        initial_messages = [ChatMessage.from_user("What's the weather like in Paris?")]
+        component = AnthropicChatGenerator()  # No streaming callback during initialization
+
+        counter = 0
+        responses = ""
+
+        # Create a callback that's compatible with async operations
+        async def callback(chunk: StreamingChunk) -> None:
+            nonlocal counter
+            nonlocal responses
+            counter += 1
+            responses += chunk.content if chunk.content else ""
+            assert chunk.component_info is not None
+            assert chunk.component_info.type.endswith("chat_generator.AnthropicChatGenerator")
+
+        # Run the async streaming test
+        results = await component.run_async(messages=initial_messages, streaming_callback=callback)
+
+        # Verify the results
+        assert len(results["replies"]) == 1
+        message = results["replies"][0]
+        assert "paris" in message.text.lower()
+        assert "claude-sonnet-4-20250514" in message.meta["model"]
+        assert message.meta["finish_reason"] == "end_turn"
+
+        # Verify streaming behavior
+        assert counter > 1  # Should have received multiple chunks
+        assert "paris" in responses.lower()  # Should have received the response in chunks
+
+    @pytest.mark.asyncio
+    @pytest.mark.skipif(
+        not os.environ.get("ANTHROPIC_API_KEY", None),
+        reason="Export an env var called ANTHROPIC_API_KEY containing the Anthropic API key to run this test.",
+    )
+    @pytest.mark.integration
+    async def test_live_run_async_with_tools(self, tools):
+        """
+        Integration test that the async run method works with tools.
+        """
+        initial_messages = [ChatMessage.from_user("What's the weather like in Paris?")]
+        component = AnthropicChatGenerator(tools=tools)
+        results = await component.run_async(messages=initial_messages)
+
+        assert len(results["replies"]) == 1
+        message = results["replies"][0]
+
+        assert message.tool_calls
+        tool_call = message.tool_call
+        assert isinstance(tool_call, ToolCall)
+        assert tool_call.id is not None
+        assert tool_call.tool_name == "weather"
+        assert tool_call.arguments == {"city": "Paris"}
+        assert message.meta["finish_reason"] == "tool_use"
+
+        new_messages = [
+            *initial_messages,
+            message,
+            ChatMessage.from_tool(tool_result="22° C", origin=tool_call),
+        ]
+        results = await component.run_async(new_messages)
+        assert len(results["replies"]) == 1
+        final_message = results["replies"][0]
+        assert not final_message.tool_calls
+        assert len(final_message.text) > 0
+        assert "paris" in final_message.text.lower()
